|
| Haskore.Interface.SuperCollider.Schedule.Install |
|
|
| Description |
| This is a variant of the Haskore.Interface.SuperCollider.Schedule module.
Instead of an abstract Instrument type
and a Haskore.Interface.SuperCollider.SoundMap,
we attach SuperCollider instrument information to each note.
|
|
| Synopsis |
|
|
|
| Documentation |
|
|
| The [OSC] state is used for messages for installing the instruments.
We cannot use a Writer monad for this purpose
because we have to read the generated messages for playMusic.
| | Constructors | | Instances | |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
| data SoundAttributes params | Source |
|
| Constructors | | Instances | |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
| Produced by Haddock version 2.6.0 |